# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).


## [0.8] - 2023-01-12

### Added
- Version (-v) flag and version information to the about section

### Changed
- Don't display -0 when overstudying (go to -1 immediately)
- Migrate to GPLv3


## [0.7.2] - 2022-07-02

### Added
- Infinite study (when cycles are set to 0)
- Status label (for more apparent pausing)

### Changed
- Set plant age to max when swapping to another one
- Enable breaking earlier when not overstudying
- Break now overstudies too
- Fix pauses and studies sometimes not being saved correctly


## [0.7.1] - 2022-06-25

### Changed
- Fix broken installation
